pub enum Domain {
Merkle4,
Merkle2,
Encryption,
Other,
}Expand description
The Domain Separation for Poseidon
Variants
Merkle4
Domain to specify hashing of 4-arity merkle tree.
Note that selecting this domain-separator means that the total hash
input must be exactly 4 BlsScalar long, and any empty slots of the
merkle tree level need to be filled with the zero element.
Merkle2
Domain to specify hashing of 2-arity merkle tree
Note that selecting this domain-separator means that the total hash
input must be exactly 2 BlsScalar long, and any empty slots of the
merkle tree level need to be filled with the zero element.
Encryption
Domain to specify hash used for encryption
Other
Domain to specify hash for any other input