pub struct Hash<'a> { /* private fields */ }Expand description
Hash any given input into one or several scalar using the Hades
permutation strategy. The Hash can absorb multiple chunks of input but will
only call squeeze once at the finalization of the hash.
The output length is set to 1 element per default, but this can be
overridden with Hash::output_len.
Implementations
Sourceimpl<'a> Hash<'a>
impl<'a> Hash<'a>
Sourcepub fn output_len(&mut self, output_len: usize)
pub fn output_len(&mut self, output_len: usize)
Override the length of the hash output (default value is 1) when using the hash for anything other than hashing a merkle tree or encryption.
Sourcepub fn finalize(&self) -> Vec<BlsScalar>
pub fn finalize(&self) -> Vec<BlsScalar>
Finalize the hash.
Panics
This function panics when the io-pattern can not be created with the
given domain and input, e.g. using Domain::Merkle4 with an input
anything other than 4 Scalar.
Sourcepub fn finalize_truncated(&self) -> Vec<JubJubScalar>
pub fn finalize_truncated(&self) -> Vec<JubJubScalar>
Finalize the hash and output the result as a JubJubScalar by
truncating the BlsScalar output to 250 bits.
Panics
This function panics when the io-pattern can not be created with the
given domain and input, e.g. using Domain::Merkle4 with an input
anything other than 4 Scalar.
Sourcepub fn digest(domain: Domain, input: &'a [BlsScalar]) -> Vec<BlsScalar>
pub fn digest(domain: Domain, input: &'a [BlsScalar]) -> Vec<BlsScalar>
Digest an input and calculate the hash immediately
Panics
This function panics when the io-pattern can not be created with the
given domain and input, e.g. using Domain::Merkle4 with an input
anything other than 4 Scalar.
Sourcepub fn digest_truncated(
domain: Domain,
input: &'a [BlsScalar],
) -> Vec<JubJubScalar>
pub fn digest_truncated( domain: Domain, input: &'a [BlsScalar], ) -> Vec<JubJubScalar>
Digest an input and calculate the hash as jubjub-scalar immediately
Panics
This function panics when the io-pattern can not be created with the
given domain and input, e.g. using Domain::Merkle4 with an input
anything other than 4 Scalar.